@@ -67,6 +67,9 @@ class SMBus:
     def read_byte_data(self, address, reg):
         return 0x00
 
+    def write_byte(self, address, byte):
+        pass
+
 class pylirc:
     
     def init(a = "pylirc", b = "./conf", c = None):
@@ -78,4 +81,8 @@ class pylirc:
     def exit():
         pass
 
-    
\ No newline at end of file
+class PCF8574:
+
+    def __init__(self, sm, i2c_addr):
+        self.port = [0]*8
+    
